@@ -17,7 +17,6 @@ from .exceptions import DisallowedPath
 from .exceptions import Unauthorized
 from .journal import Journal
 from .parse import BeautifulSoup
-from .parse import check_page
 from .parse import check_page_raise
 from .parse import parse_loggedin_user
 from .parse import parse_page
@@ -33,6 +32,7 @@ from .user import User
 from .user import UserPartial
 
 
+# noinspection GrazieInspection
 class FAAPI:
     """
     This class provides the methods to access and parse Fur Affinity pages and retrieve objects.
@@ -311,60 +311,3 @@ class FAAPI:
             _user.status = s
             users.append(_user)
         return users, (page + 1) if np else 0
-
-    def user_exists(self, user: str) -> int:
-        """
-        Check if a user exists.
-
-        :param user: The name of the user (_ characters are allowed).
-        :return: 0 okay, 1 account disabled, 2 system error, 3 unknown error, 4 request error.
-        """
-
-        if not (res := self.get(join_url("user", username_url(user)))).ok:
-            return 4
-        elif (check := check_page(parse_page(res.text))) == 0:
-            return 0
-        elif check == 3:
-            return 1
-        elif check == 4:
-            return 2
-        else:
-            return 3
-
-    def submission_exists(self, submission_id: int) -> int:
-        """
-        Check if a submission exists.
-
-        :param submission_id: The ID of the submission.
-        :return: 0 okay, 1 account disabled, 2 system error, 3 unknown error, 4 request error.
-        """
-
-        if not (res := self.get(join_url("view", submission_id))).ok:
-            return 4
-        elif (check := check_page(parse_page(res.text))) == 0:
-            return 0
-        elif check == 3:
-            return 1
-        elif check == 4:
-            return 2
-        else:
-            return 3
-
-    def journal_exists(self, journal_id: int) -> int:
-        """
-        Check if a journal exists.
-
-        :param journal_id: The ID of the journal.
-        :return: 0 okay, 1 account disabled, 2 system error, 3 unknown error, 4 request error.
-        """
-
-        if not (res := self.get(join_url("journal", journal_id))).ok:
-            return 4
-        elif (check := check_page(parse_page(res.text))) == 0:
-            return 0
-        elif check == 3:
-            return 1
-        elif check == 4:
-            return 2
-        else:
-            return 3
